@@ -4,19 +4,22 @@
 #' @importClassesFrom GenomicRanges GRangesList
 #' @importFrom S4Vectors mcols
 #' @importFrom BiocGenerics relist
-#' @importFrom GenomeInfoDb seqinfo seqinfo<-
+#' @importFrom Seqinfo seqinfo seqinfo<-
 #' @importFrom MatrixGenerics rowRanges
 #' @importFrom SummarizedExperiment rowRanges<-
 #' @importFrom stats setNames
 NULL
 
 #' @exportClass RaggedExperiment
-.RaggedExperiment <- setClass("RaggedExperiment",
+.RaggedExperiment <- setClass(
+    "RaggedExperiment",
     slots = c(
         assays = "GRangesList",
         rowidx = "integer",
-        colidx = "integer"),
-    contains = "Annotated")
+        colidx = "integer"
+    ),
+    contains = "Annotated"
+)
 
 .valid.RaggedExperiment.idx <- function(x) {
     txt <- character()
@@ -101,23 +104,29 @@ setValidity2("RaggedExperiment", .valid.RaggedExperiment)
 #'
 #' \code{as(object, "GRangesList")}:
 #'
-#' Creates a \linkS4class{GRangesList} object from a \code{RaggedExperiment}.
+#' Creates a \link[GenomicRanges]{GRangesList} object from a
+#' \code{RaggedExperiment}.
 #'
 #' \code{as(from, "RaggedExperiment")}:
 #'
-#' Creates a \code{RaggedExperiment} object from a \linkS4class{GRangesList},
-#' or \linkS4class{GRanges} object.
+#' Creates a \code{RaggedExperiment} object from a
+#' \link[GenomicRanges]{GRangesList}, or \link[GenomicRanges]{GRanges} object.
 #'
 #' @param ... Constructor: GRanges, list of GRanges, or GRangesList OR
 #'     assay: Additional arguments for assay. See details for more information.
-#' @param colData A \code{\link{DataFrame}} describing samples. Length of
-#'     rowRanges must equal the number of rows in colData
+#'
+#' @param colData A \code{\link[S4Vectors]{DataFrame}} describing samples.
+#'   Length of rowRanges must equal the number of rows in colData
+#'
+#' @param metadata A \code{list} to include in the metadata. Any metadata
+#'   included in the input objects are lost.
+#'
 #' @return constructor returns a \code{RaggedExperiment} object
 #'
 #' @example inst/scripts/RaggedExperiment-Ex.R
 #'
 #' @export
-RaggedExperiment <- function(..., colData=DataFrame()) {
+RaggedExperiment <- function(..., colData=DataFrame(), metadata = list()) {
     inputs <- list(...)
     if (length(inputs) == 1L && is(inputs[[1L]], "GenomicRangesList")) {
         GRList <- inputs[[1L]]
@@ -155,7 +164,8 @@ RaggedExperiment <- function(..., colData=DataFrame()) {
     .RaggedExperiment(
         assays = rowRanges,
         rowidx = seq_len(sum(lengths(rowRanges))),
-        colidx = seq_along(rowRanges)
+        colidx = seq_along(rowRanges),
+        metadata = metadata
     )
 }
 
@@ -205,7 +215,7 @@ setMethod("seqinfo", "RaggedExperiment", function(x) {
 
 #' @describeIn RaggedExperiment Replace seqinfo metadata of the ranges
 #' @exportMethod seqinfo<-
-#' @inheritParams GenomeInfoDb::`seqinfo<-`
+#' @inheritParams Seqinfo::`seqinfo<-`
 setReplaceMethod("seqinfo", "RaggedExperiment",
     function(x, new2old=NULL, pruning.mode=c("error", "coarse", "fine", "tidy"),
         value) {
@@ -215,7 +225,7 @@ setReplaceMethod("seqinfo", "RaggedExperiment",
 })
 
 #' @describeIn RaggedExperiment rowRanges accessor
-#' @return 'rowRanges' returns a \code{\link{GRanges}} object
+#' @return 'rowRanges' returns a \code{\link[GenomicRanges]{GRanges}} object
 #'     summarizing ranges corresponding to \code{assay()} rows.
 #' @exportMethod rowRanges
 setMethod("rowRanges", "RaggedExperiment", function(x, ...) {
@@ -237,7 +247,7 @@ setReplaceMethod("rowRanges", c("RaggedExperiment", "GRanges"),
 
 #' @describeIn RaggedExperiment get the metadata columns of the ranges,
 #'     rectangular representation of the 'assays'
-#' @return 'mcols' returns a \code{\link{DataFrame}} object
+#' @return 'mcols' returns a \code{\link[S4Vectors]{DataFrame}} object
 #'     of the metadata columns
 #' @param use.names (logical default FALSE) whether to propagate rownames from
 #' the object to rownames of metadata \code{DataFrame}
@@ -335,7 +345,7 @@ setReplaceMethod("dimnames", c("RaggedExperiment", "ANY"),
 })
 
 #' @describeIn RaggedExperiment get the length of row vectors in the object,
-#'     similar to \linkS4class{SummarizedExperiment}
+#'   similar to \link[SummarizedExperiment]{SummarizedExperiment}
 #' @exportMethod length
 setMethod("length", "RaggedExperiment", function(x) {
     length(.rowidx(x))
@@ -380,7 +390,7 @@ setMethod("assay", c("RaggedExperiment", "ANY"),
 #' @param x A RaggedExperiment object.
 #' @param withDimnames logical (default TRUE) whether to use dimension names
 #' in the resulting object
-#' @return 'assays' returns a \code{\link{SimpleList}}
+#' @return 'assays' returns a \code{\link[S4Vectors]{SimpleList}}
 #' @exportMethod assays
 setMethod("assays", "RaggedExperiment", function(x, withDimnames = TRUE, ...) {
     nms <- names(.mcols(x))
